
/**
  Company:
    Microchip Technology Inc.

  File Name:
 LED_Array.c
 
Author:
Willem J Smit
willem.jsmit@microchip.com 

  Summary:
 * 8x32 LED array driver.

  Description:
    This header file provides implementations for driver APIs for all modules selected in the GUI.
    Generation Information :
        Product Revision  :  MPLAB? Code Configurator - v3.00
        Device            :  PIC16F1619
        Driver Version    :  2.00
    The generated drivers are tested against the following:
        Compiler          :  XC8 v1.35
        MPLAB             :  MPLAB X v3.20
 */

/*
Copyright (c) 2013 - 2015 released Microchip Technology Inc.  All rights reserved.

Microchip licenses to you the right to use, modify, copy and distribute
Software only when embedded on a Microchip microcontroller or digital signal
controller that is integrated into your product or third party product
(pursuant to the sublicense terms in the accompanying license agreement).

You should refer to the license agreement accompanying this Software for
additional information regarding your rights and obligations.

SOFTWARE AND DOCUMENTATION ARE PROVIDED "AS IS" WITHOUT WARRANTY OF ANY KIND,
EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION, ANY WARRANTY OF
MERCHANTABILITY, TITLE, NON-INFRINGEMENT AND FITNESS FOR A PARTICULAR PURPOSE.
IN NO EVENT SHALL MICROCHIP OR ITS LICENSORS BE LIABLE OR OBLIGATED UNDER
CONTRACT, NEGLIGENCE, STRICT LIABILITY, CONTRIBUTION, BREACH OF WARRANTY, OR
OTHER LEGAL EQUITABLE THEORY ANY DIRECT OR INDIRECT DAMAGES OR EXPENSES
INCLUDING BUT NOT LIMITED TO ANY INCIDENTAL, SPECIAL, INDIRECT, PUNITIVE OR
CONSEQUENTIAL DAMAGES, LOST PROFITS OR LOST DATA, COST OF PROCUREMENT OF
SUBSTITUTE GOODS, TECHNOLOGY, SERVICES, OR ANY CLAIMS BY THIRD PARTIES
(INCLUDING BUT NOT LIMITED TO ANY DEFENSE THEREOF), OR OTHER SIMILAR COSTS.
 */

#include "mcc_generated_files/mcc.h"
#include "LED_Array.h"

#define BrightnessMAX   50

void loadBuffer(char *userText) {
    //Load the userText char string into individual locations in the WriteBuffer array
    for (CNT = 0; CNT < 256; CNT++) {
        WriteBuffer[CNT] = *userText++;
    }
}

void writeLEDArray(void) {
    //Write WS2812 LEDS
    if (ColorFontGREEN>BrightnessMAX ) ColorFontGREEN = BrightnessMAX ;
    if (ColorFontRED>BrightnessMAX ) ColorFontRED = BrightnessMAX ;
    if (ColorFontBLUE>BrightnessMAX ) ColorFontBLUE = BrightnessMAX ;
    if (ColorBackGREEN>BrightnessMAX ) ColorBackGREEN = BrightnessMAX ;
    if (ColorBackRED>BrightnessMAX ) ColorBackRED = BrightnessMAX ;
    if (ColorBackBLUE>BrightnessMAX ) ColorBackBLUE = BrightnessMAX ;
    
    
    
    for (CNT = 0; CNT < 256; ++CNT) {
        StateTest = (WriteArray[CNT]); // Test AsciiBitMap bitmap for font or background
        if (StateTest == 1) { //Write characters
            SSP1BUF = ColorFontGREEN; //Green
            while (!SSP1STATbits.BF);
            SSP1BUF = ColorFontRED; //Red
            while (!SSP1STATbits.BF);
            SSP1BUF = ColorFontBLUE; //Blue 
            while (!SSP1STATbits.BF);
        }
        if (StateTest == 0) { //Write background color
            SSP1BUF = ColorBackGREEN; //Green
            while (!SSP1STATbits.BF);
            SSP1BUF = ColorBackRED; //Red
            while (!SSP1STATbits.BF);
            SSP1BUF = ColorBackBLUE; //Blue 
            while (!SSP1STATbits.BF);
        }
    }
    __delay_ms(20);
    
}

void loadLEDArray(void) { //Store, shift and update array
    //Load FormatArray with WriteArray to make updates   
    for (CNT = 0; CNT < 256; ++CNT) {
        FormatArray[CNT] = WriteArray[CNT]; //Store current state of write array. Which will later be modified and updated. 
    }
    ArrayIndex = 0;
    for (AI = 0; AI <= 30; AI++) { //Shift all characters over one column
        RowStep = 15;
        for (CNT = 0; CNT < 8; CNT++) {
            WriteArray[ArrayIndex + RowStep] = FormatArray[ArrayIndex];
            RowStep = RowStep - 2;
            ++ArrayIndex;
        }
    }
    for (CNT = 0; CNT < 8; CNT++) { //Add new character values from AsciiBitMap to column one of WriteArray

        if (WriteBuffer[BufferInc] == 32) {
            WriteArray[CNT] = AsciiBitMap[0][LI]; //Check for SPACE and end of word.
            ++LI;
            WriteComplete = 1; //End of word. Set flag for TMR1 interrupt user code to banner switch
        }

        if ((WriteBuffer[BufferInc] >= 33) && (WriteBuffer[BufferInc] <= 126)) { //Test for defined characters (AsciiBitMap). 
            WriteArray[CNT] = AsciiBitMap[WriteBuffer[BufferInc] - 32][LI]; //Move AsciiBitMap to format array
            ++LI;
            WriteComplete = 0;
        } else {
            WriteArray[CNT] = AsciiBitMap[0][LI]; //Any character which is not defined will print as a space
            ++LI;
        }
    }
    NOP();
    if (LI >= 48) { //6*8=48 AsciiBitMap// characters complete
        LI = 0;
        BufferInc++; //Move to next characters in buffer
    }
    if (WriteBuffer[BufferInc] == 0) { //Check for end of userText. If end reset BufferInc to loop text. 
        BufferInc = 0;
    }
}

void clearLEDArray(void) {
    for (CNT = 0; CNT < 256; ++CNT) {
        SSP1BUF = 0;
        while (!SSP1STATbits.BF);
    }
}




/**
 End of File
 */
